@@ -42,7 +42,7 @@ public:
 	/**
 	 * @brief destructor
 	 */
-	virtual ~KGpgEditKeyTransaction();
+    ~KGpgEditKeyTransaction() override;
 
 	/**
 	 * @brief return the id of the key we are editing
